==> hexalate_1.0.2.orig.tar.bz2: hexalate-1.0.2/translations/hexalate_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>Gegenwärtiges Spiel abbrechen?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Richtig gelöst</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Letztes Spiel konnte nicht geladen werden. Ein neues Spiel wird gestartet.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="34"/>
        <location filename="../src/window.cpp" line="75"/>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="47"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Anwendungssprache...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="51"/>
        <source>About &amp;Qt</source>
        <translation>Info über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>About Hexalate</source>
        <translation>Info über Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>A color matching game</source>
        <translation>Ein Farbabstimmungsspiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
</TS>

==> hexalate_1.0.3.orig.tar.bz2: hexalate-1.0.3/translations/hexalate_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>Gegenwärtiges Spiel abbrechen?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Richtig gelöst</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Letztes Spiel konnte nicht geladen werden. Ein neues Spiel wird gestartet.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="33"/>
        <location filename="../src/window.cpp" line="74"/>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="40"/>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="45"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Anwendungssprache...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="48"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;About</source>
        <translation>Üb&amp;er</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="73"/>
        <source>About Hexalate</source>
        <translation>Über Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="75"/>
        <source>A color matching game</source>
        <translation>Ein Farbabstimmungsspiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
</TS>
